rem ***********************************************
rem *                                             *
rem * Skript na konfiguraci 802.1x na kolejích JO *
rem *                                             *
rem * Ostravská univerzita                        *
rem * Martin Kozelský, martin.kozelsky@osu.cz     *
rem * Datum: 06.01.2022                           *
rem * verze 1.2                                   *
rem *                                             *
rem ***********************************************

@echo off
REM change CHCP to UTF-8
chcp 65001
cls

echo ##########################################################
echo #                                                        #
echo #  Nastavení ethernetového připojení na kolejích JO      #
echo #  Configuration of ethernet connection at JO dormitory  #
echo #                                                        #
echo ##########################################################

setlocal enabledelayedexpansion

:CDWORKDIR
rem Prepnutí do adresáře, ve kterém se spouští tento skript
cd /D "%~dp0"

:JEADMIN
rem Kontrola zda-li mám administratorské oprávnění
net session > nul 2>&1
if %ErrorLevel% equ 0 goto VERZE
echo.
echo Nedostatečná práva. Musíte spustit tento skript jako správce^^!
echo Insufficient rights. You have to run this script as administrator^^!
goto ERR

:VERZE
rem Kontrola verze operačního systému
if not "%OS%"=="Windows_NT" goto ERR
ver
echo.
ver | findstr /C:"Version 11." > nul
if %ErrorLevel% equ 0 goto W11
ver | findstr /C:"Version 10." > nul
if %ErrorLevel% equ 0 goto W10
ver | findstr /C:"Version 8." > nul
if %ErrorLevel% equ 0 goto W8
echo Tento operační systém není Windows 11, 10 nebo 8.
echo This OS is not Windows 11, 10 or 8.
goto ERR

:W11
:W10
:W8

:VYPIS
rem Výpis síťových připojení
echo Výpis síťových připojení a jejich MAC adres (MAC adresa = fyzická adresa):
echo List of network adapters and their MAC addresses (MAC address = physical address):
echo.
wmic nic where "AdapterType like '%%Ethernet 802.3%%' and PhysicalAdapter='TRUE' and (Name like '%%ethernet%%' or NetConnectionID like '%%ethernet%%')" get NetConnectionID,Name,MACAddress
echo ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

:VOLBA
rem Volba správného síťového připojení
echo Vyber správné jméno síťového připojení (NetConnectionID) z výše uvedených (zkopíruj celý název).
echo Choose the right LAN Connection Name (NetConnectionID) from the top listing (copy the full name).
echo.
:OPAKUJ1
set /p int=Jméno síťového připojení / LAN Connection Name -^> NetConnectionID:  
if "%int%"=="" goto OPAKUJ1
netsh int show int name=%int% > nul
if %ErrorLevel% equ 0 goto MACADRESA
echo.
echo Neexistující jméno připojení.
echo Non-existing Connection Name.
echo.
goto OPAKUJ1

:MACADRESA
rem MAC adresu je nutné registrovat v portálu OU
color 1e
echo.
echo =~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=
echo.
echo    Nezapomeňte MAC adresu registrovat v portálu OU ^^!
echo.
echo  Don't forget to register the MAC address in OU portal ^^!
echo.
echo =~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=
echo.
wmic nic where NetConnectionID="%int%" get MACAddress

:CODELAT
rem Volba instalace nebo odinstalace nastavení
echo Chcete konfiguraci instalovat (1) nebo odinstalovat (2)?
echo Do you want to install the configuration (1) or uninstall (2)?
:OPAKUJ2
set /p volba=Volba / Option:  
if "%volba%"=="1" goto INSTALL
if "%volba%"=="2" goto UNINSTALL
goto OPAKUJ2

:INSTALL
echo.
echo Instalace konfigurace...
echo Configuration installing...
echo.

:SERVICEINST
rem Start služby Wired AutoConfig Service
sc config dot3svc start=auto > nul
net start dot3svc > nul

:DHCPINST
rem Nastavení DHCP a dynamické získávání IP adres DNS a WINS serverů
netsh int ip set addr name=%int% dhcp > nul
netsh int ip set dns name=%int% dhcp > nul
netsh int ip set wins name=%int% dhcp > nul

:PROFILINST
rem Nastavení profilu s 802.1x ověřováním
netsh lan add profile filename=%CD%\DormitoryON.xml interface=%int% > nul
goto OBNOVA

:UNINSTALL
echo.
echo Odinstalace konfigurace...
echo Configuration uninstalling...
echo.

:PROFILUNINST
rem Nastavení standardního profilu bez 802.1x ověřování
netsh lan add profile filename=%CD%\DormitoryOFF.xml interface=%int% > nul

:SERVICEUNINST
rem Zastavení služby Wired AutoConfig Service
sc config dot3svc start=demand > nul
net stop dot3svc > nul

:OBNOVA
rem Obnova DNS cache a DHCP IP adresy
ipconfig /flushdns > nul
ipconfig /release %int% > nul
ipconfig /renew %int% > nul

:OK
rem Vše proběhlo v pořádku
color a0
echo #################
echo # Hotovo / Done #
echo #################
pause
exit 0

:ERR
rem Došlo k chybě
color 4f
echo.
echo #################
echo # Chyba / Error #
echo #################
pause
exit 1
